// -*- c++ -*-
//  Generated by gtkmmproc from ./../dialog.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_DIALOG_P_H
#define _GNOMEMM_DIALOG_P_H
#include <gtk--/private/window_p.h>

namespace Gnome
{
class Dialog_Class
{
public:

  typedef Dialog           CppObjectType;
  typedef GnomeDialog           BaseObjectType;
  typedef GnomeDialogClass      BaseClassType;
  typedef Gtk::Window_Class     CppClassParent;
  typedef GtkWindowClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  static void clicked_callback(GnomeDialog* o_,gint p0);
  static gboolean close_callback(GnomeDialog* o_);
  // Data
  GtkType type;
};

}
#endif
