// -*- c++ -*-
//  Generated by gtkmmproc from ./../druid-page-finish.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_DRUID_PAGE_FINISH_H
#define _GNOMEMM_DRUID_PAGE_FINISH_H

/* $Id: druid-page-finish.gen_h,v 1.6 2001/04/24 14:39:35 murrayc Exp $ */


/* druid-page-finish.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gnome--/druid-page.h>
#include <libgnomeui/gnome-druid-page-finish.h>
#include <gnome--/imlib.h>

namespace Gnome {
class DruidPageFinish;
class DruidPageFinish_Class;
}
namespace Gtk { Gnome::DruidPageFinish *wrap (GnomeDruidPageFinish *o); }
namespace Gnome
{
class DruidPageFinish : public DruidPage
{

public:
  typedef DruidPageFinish          CppObjectType;
  typedef DruidPageFinish_Class    CppClassType;
  typedef GnomeDruidPageFinish           BaseObjectType;
  typedef GnomeDruidPageFinishClass      BaseClassType;

private:
  friend class DruidPageFinish_Class;
  static CppClassType druid_page_finish_class;

  DruidPageFinish(const DruidPageFinish&);
  DruidPageFinish& operator=(const DruidPageFinish&); // not implemented

protected:
  void   initialize_class();
  explicit DruidPageFinish(GnomeDruidPageFinish *castitem);

public:
  static GtkType get_type();
  GnomeDruidPageFinish* gtkobj()             { return (GnomeDruidPageFinish*)(gtkobject); }
  const GnomeDruidPageFinish* gtkobj() const { return (GnomeDruidPageFinish*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~DruidPageFinish();

private:

public:
  DruidPageFinish();
  DruidPageFinish(const Gtk::string &title,
      const Gtk::string &text,
			const Gdk_Imlib::Image &logo_image,
			const Gdk_Imlib::Image &watermark);





  void set_bg_color(const Gdk_Color& color);


  void set_textbox_color(const Gdk_Color& color);


  void set_logo_bg_color(const Gdk_Color& color);


  void set_title_color(const Gdk_Color& color);


  void set_text_color(const Gdk_Color& color);


  void set_text(const Gtk::string& text);


  void set_title(const Gtk::string& title);


  void set_logo(const Gdk_Imlib::Image& logo_image);


  void set_watermark(const Gdk_Imlib::Image& watermark);

public:

protected:
  // impl functions

};



}


#endif
