// -*- c++ -*-
//  Generated by gtkmmproc from ./../propertybox.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_PROPERTYBOX_P_H
#define _GNOMEMM_PROPERTYBOX_P_H
#include <gnome--/private/dialog_p.h>
namespace Gnome
{
class PropertyBox_Class
{
public:

  typedef PropertyBox           CppObjectType;
  typedef GnomePropertyBox           BaseObjectType;
  typedef GnomePropertyBoxClass      BaseClassType;
  typedef Dialog_Class     CppClassParent;
  typedef GnomeDialogClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  static void apply_callback(GnomePropertyBox* o_,gint page_num);
  static void help_callback(GnomePropertyBox* o_,gint page_num);
  // Data
  GtkType type;
};

}
#endif
