// -*- c++ -*-
//  Generated by gtkmmproc from ./../color-picker.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_COLOR_PICKER_P_H
#define _GNOMEMM_COLOR_PICKER_P_H
#include <gtk--/private/button_p.h>
namespace Gnome
{
class ColorPicker_Class
{
public:

  typedef ColorPicker           CppObjectType;
  typedef GnomeColorPicker           BaseObjectType;
  typedef GnomeColorPickerClass      BaseClassType;
  typedef Gtk::Button_Class     CppClassParent;
  typedef GtkButtonClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  static void color_set_callback(GnomeColorPicker* o_,guint p0,guint p1,guint p2,guint p3);
  // Data
  GtkType type;
};

}
#endif
